# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationScreenShareEventTopicScreenShareMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationScreenShareEventTopicScreenShareMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'QueueConversationScreenShareEventTopicUriReference',
            'queue': 'QueueConversationScreenShareEventTopicUriReference',
            'team': 'QueueConversationScreenShareEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'QueueConversationScreenShareEventTopicErrorBody',
            'script': 'QueueConversationScreenShareEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'QueueConversationScreenShareEventTopicUriReference',
            'external_organization': 'QueueConversationScreenShareEventTopicUriReference',
            'wrapup': 'QueueConversationScreenShareEventTopicWrapup',
            'conversation_routing_data': 'QueueConversationScreenShareEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'QueueConversationScreenShareEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'context': 'str',
            'peer_count': 'int',
            'sharing': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'context': 'context',
            'peer_count': 'peerCount',
            'sharing': 'sharing'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._context = None
        self._peer_count = None
        self._sharing = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The id of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param id: The id of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The name of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param name: The name of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The address of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param address: The address of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The start_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param start_time: The start_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The connected_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param connected_time: The connected_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The end_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param end_time: The end_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The start_hold_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param start_hold_time: The start_hold_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The purpose of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param purpose: The purpose of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param state: The state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The direction of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param direction: The direction of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The disconnect_type of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param disconnect_type: The disconnect_type of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The held of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param held: The held of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The wrapup_required of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param wrapup_required: The wrapup_required of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The wrapup_prompt of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The user of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param user: The user of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The queue of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param queue: The queue of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The team of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param team: The team of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The attributes of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param attributes: The attributes of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The error_info of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param error_info: The error_info of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The script of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param script: The script of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The wrapup_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The wrapup_skipped of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The alerting_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The provider of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param provider: The provider of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The external_contact of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param external_contact: The external_contact of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The external_organization of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param external_organization: The external_organization of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The wrapup of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param wrapup: The wrapup of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The conversation_routing_data of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The peer of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param peer: The peer of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The screen_recording_state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The flagged_reason of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param flagged_reason: The flagged_reason of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The journey_context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: QueueConversationScreenShareEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param journey_context: The journey_context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: QueueConversationScreenShareEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The start_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param start_acw_time: The start_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The end_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param end_acw_time: The end_acw_time of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def context(self):
        """
        Gets the context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param context: The context of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: str
        """
        
        self._context = context

    @property
    def peer_count(self):
        """
        Gets the peer_count of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The peer_count of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param peer_count: The peer_count of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: int
        """
        
        self._peer_count = peer_count

    @property
    def sharing(self):
        """
        Gets the sharing of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :return: The sharing of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :rtype: bool
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """
        Sets the sharing of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.


        :param sharing: The sharing of this QueueConversationScreenShareEventTopicScreenShareMediaParticipant.
        :type: bool
        """
        
        self._sharing = sharing

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateManagementUnitSettingsRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateManagementUnitSettingsRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'adherence': 'AdherenceSettings',
            'short_term_forecasting': 'ShortTermForecastingSettings',
            'time_off': 'TimeOffRequestSettings',
            'scheduling': 'SchedulingSettingsRequest',
            'shift_trading': 'ShiftTradeSettings'
        }

        self.attribute_map = {
            'adherence': 'adherence',
            'short_term_forecasting': 'shortTermForecasting',
            'time_off': 'timeOff',
            'scheduling': 'scheduling',
            'shift_trading': 'shiftTrading'
        }

        self._adherence = None
        self._short_term_forecasting = None
        self._time_off = None
        self._scheduling = None
        self._shift_trading = None

    @property
    def adherence(self):
        """
        Gets the adherence of this CreateManagementUnitSettingsRequest.
        Adherence settings for this management unit

        :return: The adherence of this CreateManagementUnitSettingsRequest.
        :rtype: AdherenceSettings
        """
        return self._adherence

    @adherence.setter
    def adherence(self, adherence):
        """
        Sets the adherence of this CreateManagementUnitSettingsRequest.
        Adherence settings for this management unit

        :param adherence: The adherence of this CreateManagementUnitSettingsRequest.
        :type: AdherenceSettings
        """
        
        self._adherence = adherence

    @property
    def short_term_forecasting(self):
        """
        Gets the short_term_forecasting of this CreateManagementUnitSettingsRequest.
        Short term forecasting settings for this management unit.  Moving to Business Unit

        :return: The short_term_forecasting of this CreateManagementUnitSettingsRequest.
        :rtype: ShortTermForecastingSettings
        """
        return self._short_term_forecasting

    @short_term_forecasting.setter
    def short_term_forecasting(self, short_term_forecasting):
        """
        Sets the short_term_forecasting of this CreateManagementUnitSettingsRequest.
        Short term forecasting settings for this management unit.  Moving to Business Unit

        :param short_term_forecasting: The short_term_forecasting of this CreateManagementUnitSettingsRequest.
        :type: ShortTermForecastingSettings
        """
        
        self._short_term_forecasting = short_term_forecasting

    @property
    def time_off(self):
        """
        Gets the time_off of this CreateManagementUnitSettingsRequest.
        Time off request settings for this management unit

        :return: The time_off of this CreateManagementUnitSettingsRequest.
        :rtype: TimeOffRequestSettings
        """
        return self._time_off

    @time_off.setter
    def time_off(self, time_off):
        """
        Sets the time_off of this CreateManagementUnitSettingsRequest.
        Time off request settings for this management unit

        :param time_off: The time_off of this CreateManagementUnitSettingsRequest.
        :type: TimeOffRequestSettings
        """
        
        self._time_off = time_off

    @property
    def scheduling(self):
        """
        Gets the scheduling of this CreateManagementUnitSettingsRequest.
        Scheduling settings for this management unit

        :return: The scheduling of this CreateManagementUnitSettingsRequest.
        :rtype: SchedulingSettingsRequest
        """
        return self._scheduling

    @scheduling.setter
    def scheduling(self, scheduling):
        """
        Sets the scheduling of this CreateManagementUnitSettingsRequest.
        Scheduling settings for this management unit

        :param scheduling: The scheduling of this CreateManagementUnitSettingsRequest.
        :type: SchedulingSettingsRequest
        """
        
        self._scheduling = scheduling

    @property
    def shift_trading(self):
        """
        Gets the shift_trading of this CreateManagementUnitSettingsRequest.
        Shift trade settings for this management unit

        :return: The shift_trading of this CreateManagementUnitSettingsRequest.
        :rtype: ShiftTradeSettings
        """
        return self._shift_trading

    @shift_trading.setter
    def shift_trading(self, shift_trading):
        """
        Sets the shift_trading of this CreateManagementUnitSettingsRequest.
        Shift trade settings for this management unit

        :param shift_trading: The shift_trading of this CreateManagementUnitSettingsRequest.
        :type: ShiftTradeSettings
        """
        
        self._shift_trading = shift_trading

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'reviewed_by': 'WfmBulkShiftTradeStateUpdateNotificationTopicUserReference',
            'reviewed_date': 'datetime',
            'failure_reason': 'str',
            'metadata': 'WfmBulkShiftTradeStateUpdateNotificationTopicWfmVersionedEntityMetadata'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'reviewed_by': 'reviewedBy',
            'reviewed_date': 'reviewedDate',
            'failure_reason': 'failureReason',
            'metadata': 'metadata'
        }

        self._id = None
        self._state = None
        self._reviewed_by = None
        self._reviewed_date = None
        self._failure_reason = None
        self._metadata = None

    @property
    def id(self):
        """
        Gets the id of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The id of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param id: The id of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The state of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param state: The state of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: str
        """
        allowed_values = ["Unmatched", "Matched", "Approved", "Denied", "Expired", "Canceled"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def reviewed_by(self):
        """
        Gets the reviewed_by of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The reviewed_by of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: WfmBulkShiftTradeStateUpdateNotificationTopicUserReference
        """
        return self._reviewed_by

    @reviewed_by.setter
    def reviewed_by(self, reviewed_by):
        """
        Sets the reviewed_by of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param reviewed_by: The reviewed_by of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: WfmBulkShiftTradeStateUpdateNotificationTopicUserReference
        """
        
        self._reviewed_by = reviewed_by

    @property
    def reviewed_date(self):
        """
        Gets the reviewed_date of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The reviewed_date of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: datetime
        """
        return self._reviewed_date

    @reviewed_date.setter
    def reviewed_date(self, reviewed_date):
        """
        Sets the reviewed_date of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param reviewed_date: The reviewed_date of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: datetime
        """
        
        self._reviewed_date = reviewed_date

    @property
    def failure_reason(self):
        """
        Gets the failure_reason of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The failure_reason of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: str
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """
        Sets the failure_reason of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param failure_reason: The failure_reason of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: str
        """
        allowed_values = ["InitiatingAgentScheduleNotFound", "InitiatingAgentShiftNotFound", "ReceivingAgentNotFound", "ReceivingAgentScheduleNotFound", "ReceivingAgentShiftNotFound", "ScheduleNotPublished", "TransitionNotAllowed"]
        if failure_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for failure_reason -> " + failure_reason)
            self._failure_reason = "outdated_sdk_version"
        else:
            self._failure_reason = failure_reason

    @property
    def metadata(self):
        """
        Gets the metadata of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :return: The metadata of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :rtype: WfmBulkShiftTradeStateUpdateNotificationTopicWfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.


        :param metadata: The metadata of this WfmBulkShiftTradeStateUpdateNotificationTopicBulkShiftTradeStateUpdateResult.
        :type: WfmBulkShiftTradeStateUpdateNotificationTopicWfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsFlow(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsFlow - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flow_id': 'str',
            'flow_name': 'str',
            'flow_version': 'str',
            'flow_type': 'str',
            'exit_reason': 'str',
            'entry_reason': 'str',
            'entry_type': 'str',
            'transfer_type': 'str',
            'transfer_target_name': 'str',
            'transfer_target_address': 'str',
            'issued_callback': 'bool',
            'starting_language': 'str',
            'ending_language': 'str',
            'outcomes': 'list[AnalyticsFlowOutcome]'
        }

        self.attribute_map = {
            'flow_id': 'flowId',
            'flow_name': 'flowName',
            'flow_version': 'flowVersion',
            'flow_type': 'flowType',
            'exit_reason': 'exitReason',
            'entry_reason': 'entryReason',
            'entry_type': 'entryType',
            'transfer_type': 'transferType',
            'transfer_target_name': 'transferTargetName',
            'transfer_target_address': 'transferTargetAddress',
            'issued_callback': 'issuedCallback',
            'starting_language': 'startingLanguage',
            'ending_language': 'endingLanguage',
            'outcomes': 'outcomes'
        }

        self._flow_id = None
        self._flow_name = None
        self._flow_version = None
        self._flow_type = None
        self._exit_reason = None
        self._entry_reason = None
        self._entry_type = None
        self._transfer_type = None
        self._transfer_target_name = None
        self._transfer_target_address = None
        self._issued_callback = None
        self._starting_language = None
        self._ending_language = None
        self._outcomes = None

    @property
    def flow_id(self):
        """
        Gets the flow_id of this AnalyticsFlow.
        The unique identifier of this flow

        :return: The flow_id of this AnalyticsFlow.
        :rtype: str
        """
        return self._flow_id

    @flow_id.setter
    def flow_id(self, flow_id):
        """
        Sets the flow_id of this AnalyticsFlow.
        The unique identifier of this flow

        :param flow_id: The flow_id of this AnalyticsFlow.
        :type: str
        """
        
        self._flow_id = flow_id

    @property
    def flow_name(self):
        """
        Gets the flow_name of this AnalyticsFlow.
        The name of this flow

        :return: The flow_name of this AnalyticsFlow.
        :rtype: str
        """
        return self._flow_name

    @flow_name.setter
    def flow_name(self, flow_name):
        """
        Sets the flow_name of this AnalyticsFlow.
        The name of this flow

        :param flow_name: The flow_name of this AnalyticsFlow.
        :type: str
        """
        
        self._flow_name = flow_name

    @property
    def flow_version(self):
        """
        Gets the flow_version of this AnalyticsFlow.
        The version of this flow

        :return: The flow_version of this AnalyticsFlow.
        :rtype: str
        """
        return self._flow_version

    @flow_version.setter
    def flow_version(self, flow_version):
        """
        Sets the flow_version of this AnalyticsFlow.
        The version of this flow

        :param flow_version: The flow_version of this AnalyticsFlow.
        :type: str
        """
        
        self._flow_version = flow_version

    @property
    def flow_type(self):
        """
        Gets the flow_type of this AnalyticsFlow.
        The type of this flow

        :return: The flow_type of this AnalyticsFlow.
        :rtype: str
        """
        return self._flow_type

    @flow_type.setter
    def flow_type(self, flow_type):
        """
        Sets the flow_type of this AnalyticsFlow.
        The type of this flow

        :param flow_type: The flow_type of this AnalyticsFlow.
        :type: str
        """
        allowed_values = ["BOT", "COMMONMODULE", "INBOUNDCALL", "INBOUNDCHAT", "INBOUNDEMAIL", "INBOUNDSHORTMESSAGE", "INQUEUECALL", "OUTBOUNDCALL", "SECURECALL", "SPEECH", "SURVEYINVITE", "WORKFLOW"]
        if flow_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flow_type -> " + flow_type)
            self._flow_type = "outdated_sdk_version"
        else:
            self._flow_type = flow_type

    @property
    def exit_reason(self):
        """
        Gets the exit_reason of this AnalyticsFlow.
        The exit reason for this flow, e.g. DISCONNECT

        :return: The exit_reason of this AnalyticsFlow.
        :rtype: str
        """
        return self._exit_reason

    @exit_reason.setter
    def exit_reason(self, exit_reason):
        """
        Sets the exit_reason of this AnalyticsFlow.
        The exit reason for this flow, e.g. DISCONNECT

        :param exit_reason: The exit_reason of this AnalyticsFlow.
        :type: str
        """
        
        self._exit_reason = exit_reason

    @property
    def entry_reason(self):
        """
        Gets the entry_reason of this AnalyticsFlow.
        The particular entry reason for this flow, e.g. an address, userId, or flowId

        :return: The entry_reason of this AnalyticsFlow.
        :rtype: str
        """
        return self._entry_reason

    @entry_reason.setter
    def entry_reason(self, entry_reason):
        """
        Sets the entry_reason of this AnalyticsFlow.
        The particular entry reason for this flow, e.g. an address, userId, or flowId

        :param entry_reason: The entry_reason of this AnalyticsFlow.
        :type: str
        """
        
        self._entry_reason = entry_reason

    @property
    def entry_type(self):
        """
        Gets the entry_type of this AnalyticsFlow.
        The entry type for this flow

        :return: The entry_type of this AnalyticsFlow.
        :rtype: str
        """
        return self._entry_type

    @entry_type.setter
    def entry_type(self, entry_type):
        """
        Sets the entry_type of this AnalyticsFlow.
        The entry type for this flow

        :param entry_type: The entry_type of this AnalyticsFlow.
        :type: str
        """
        allowed_values = ["dnis", "direct", "flow", "agent", "outbound"]
        if entry_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for entry_type -> " + entry_type)
            self._entry_type = "outdated_sdk_version"
        else:
            self._entry_type = entry_type

    @property
    def transfer_type(self):
        """
        Gets the transfer_type of this AnalyticsFlow.
        The type of transfer for flows that ended with a transfer

        :return: The transfer_type of this AnalyticsFlow.
        :rtype: str
        """
        return self._transfer_type

    @transfer_type.setter
    def transfer_type(self, transfer_type):
        """
        Sets the transfer_type of this AnalyticsFlow.
        The type of transfer for flows that ended with a transfer

        :param transfer_type: The transfer_type of this AnalyticsFlow.
        :type: str
        """
        
        self._transfer_type = transfer_type

    @property
    def transfer_target_name(self):
        """
        Gets the transfer_target_name of this AnalyticsFlow.
        The name of a transfer target

        :return: The transfer_target_name of this AnalyticsFlow.
        :rtype: str
        """
        return self._transfer_target_name

    @transfer_target_name.setter
    def transfer_target_name(self, transfer_target_name):
        """
        Sets the transfer_target_name of this AnalyticsFlow.
        The name of a transfer target

        :param transfer_target_name: The transfer_target_name of this AnalyticsFlow.
        :type: str
        """
        
        self._transfer_target_name = transfer_target_name

    @property
    def transfer_target_address(self):
        """
        Gets the transfer_target_address of this AnalyticsFlow.
        The address of a transfer target

        :return: The transfer_target_address of this AnalyticsFlow.
        :rtype: str
        """
        return self._transfer_target_address

    @transfer_target_address.setter
    def transfer_target_address(self, transfer_target_address):
        """
        Sets the transfer_target_address of this AnalyticsFlow.
        The address of a transfer target

        :param transfer_target_address: The transfer_target_address of this AnalyticsFlow.
        :type: str
        """
        
        self._transfer_target_address = transfer_target_address

    @property
    def issued_callback(self):
        """
        Gets the issued_callback of this AnalyticsFlow.
        Flag indicating whether the flow issued a callback

        :return: The issued_callback of this AnalyticsFlow.
        :rtype: bool
        """
        return self._issued_callback

    @issued_callback.setter
    def issued_callback(self, issued_callback):
        """
        Sets the issued_callback of this AnalyticsFlow.
        Flag indicating whether the flow issued a callback

        :param issued_callback: The issued_callback of this AnalyticsFlow.
        :type: bool
        """
        
        self._issued_callback = issued_callback

    @property
    def starting_language(self):
        """
        Gets the starting_language of this AnalyticsFlow.
        Flow starting language, e.g. en-us

        :return: The starting_language of this AnalyticsFlow.
        :rtype: str
        """
        return self._starting_language

    @starting_language.setter
    def starting_language(self, starting_language):
        """
        Sets the starting_language of this AnalyticsFlow.
        Flow starting language, e.g. en-us

        :param starting_language: The starting_language of this AnalyticsFlow.
        :type: str
        """
        
        self._starting_language = starting_language

    @property
    def ending_language(self):
        """
        Gets the ending_language of this AnalyticsFlow.
        Flow ending language, e.g. en-us

        :return: The ending_language of this AnalyticsFlow.
        :rtype: str
        """
        return self._ending_language

    @ending_language.setter
    def ending_language(self, ending_language):
        """
        Sets the ending_language of this AnalyticsFlow.
        Flow ending language, e.g. en-us

        :param ending_language: The ending_language of this AnalyticsFlow.
        :type: str
        """
        
        self._ending_language = ending_language

    @property
    def outcomes(self):
        """
        Gets the outcomes of this AnalyticsFlow.
        Flow outcomes

        :return: The outcomes of this AnalyticsFlow.
        :rtype: list[AnalyticsFlowOutcome]
        """
        return self._outcomes

    @outcomes.setter
    def outcomes(self, outcomes):
        """
        Sets the outcomes of this AnalyticsFlow.
        Flow outcomes

        :param outcomes: The outcomes of this AnalyticsFlow.
        :type: list[AnalyticsFlowOutcome]
        """
        
        self._outcomes = outcomes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserScheduleAdherence(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserScheduleAdherence - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'UserReference',
            'management_unit': 'ManagementUnit',
            'team': 'Team',
            'scheduled_activity_category': 'str',
            'system_presence': 'str',
            'organization_secondary_presence_id': 'str',
            'routing_status': 'str',
            'actual_activity_category': 'str',
            'is_out_of_office': 'bool',
            'adherence_state': 'str',
            'impact': 'str',
            'time_of_adherence_change': 'datetime',
            'presence_update_time': 'datetime',
            'active_queues': 'list[QueueReference]',
            'active_queues_modified_time': 'datetime',
            'removed_from_management_unit': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'management_unit': 'managementUnit',
            'team': 'team',
            'scheduled_activity_category': 'scheduledActivityCategory',
            'system_presence': 'systemPresence',
            'organization_secondary_presence_id': 'organizationSecondaryPresenceId',
            'routing_status': 'routingStatus',
            'actual_activity_category': 'actualActivityCategory',
            'is_out_of_office': 'isOutOfOffice',
            'adherence_state': 'adherenceState',
            'impact': 'impact',
            'time_of_adherence_change': 'timeOfAdherenceChange',
            'presence_update_time': 'presenceUpdateTime',
            'active_queues': 'activeQueues',
            'active_queues_modified_time': 'activeQueuesModifiedTime',
            'removed_from_management_unit': 'removedFromManagementUnit',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._management_unit = None
        self._team = None
        self._scheduled_activity_category = None
        self._system_presence = None
        self._organization_secondary_presence_id = None
        self._routing_status = None
        self._actual_activity_category = None
        self._is_out_of_office = None
        self._adherence_state = None
        self._impact = None
        self._time_of_adherence_change = None
        self._presence_update_time = None
        self._active_queues = None
        self._active_queues_modified_time = None
        self._removed_from_management_unit = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UserScheduleAdherence.
        The globally unique identifier for the object.

        :return: The id of this UserScheduleAdherence.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserScheduleAdherence.
        The globally unique identifier for the object.

        :param id: The id of this UserScheduleAdherence.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UserScheduleAdherence.


        :return: The name of this UserScheduleAdherence.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserScheduleAdherence.


        :param name: The name of this UserScheduleAdherence.
        :type: str
        """
        
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this UserScheduleAdherence.
        The user for whom this status applies

        :return: The user of this UserScheduleAdherence.
        :rtype: UserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this UserScheduleAdherence.
        The user for whom this status applies

        :param user: The user of this UserScheduleAdherence.
        :type: UserReference
        """
        
        self._user = user

    @property
    def management_unit(self):
        """
        Gets the management_unit of this UserScheduleAdherence.
        The management unit to which this user belongs

        :return: The management_unit of this UserScheduleAdherence.
        :rtype: ManagementUnit
        """
        return self._management_unit

    @management_unit.setter
    def management_unit(self, management_unit):
        """
        Sets the management_unit of this UserScheduleAdherence.
        The management unit to which this user belongs

        :param management_unit: The management_unit of this UserScheduleAdherence.
        :type: ManagementUnit
        """
        
        self._management_unit = management_unit

    @property
    def team(self):
        """
        Gets the team of this UserScheduleAdherence.
        The team to which this user belongs

        :return: The team of this UserScheduleAdherence.
        :rtype: Team
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this UserScheduleAdherence.
        The team to which this user belongs

        :param team: The team of this UserScheduleAdherence.
        :type: Team
        """
        
        self._team = team

    @property
    def scheduled_activity_category(self):
        """
        Gets the scheduled_activity_category of this UserScheduleAdherence.
        Activity for which the user is scheduled

        :return: The scheduled_activity_category of this UserScheduleAdherence.
        :rtype: str
        """
        return self._scheduled_activity_category

    @scheduled_activity_category.setter
    def scheduled_activity_category(self, scheduled_activity_category):
        """
        Sets the scheduled_activity_category of this UserScheduleAdherence.
        Activity for which the user is scheduled

        :param scheduled_activity_category: The scheduled_activity_category of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if scheduled_activity_category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for scheduled_activity_category -> " + scheduled_activity_category)
            self._scheduled_activity_category = "outdated_sdk_version"
        else:
            self._scheduled_activity_category = scheduled_activity_category

    @property
    def system_presence(self):
        """
        Gets the system_presence of this UserScheduleAdherence.
        Actual underlying system presence value

        :return: The system_presence of this UserScheduleAdherence.
        :rtype: str
        """
        return self._system_presence

    @system_presence.setter
    def system_presence(self, system_presence):
        """
        Sets the system_presence of this UserScheduleAdherence.
        Actual underlying system presence value

        :param system_presence: The system_presence of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["Available", "Away", "Busy", "Offline", "Idle", "OnQueue", "Meal", "Training", "Meeting", "Break"]
        if system_presence.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for system_presence -> " + system_presence)
            self._system_presence = "outdated_sdk_version"
        else:
            self._system_presence = system_presence

    @property
    def organization_secondary_presence_id(self):
        """
        Gets the organization_secondary_presence_id of this UserScheduleAdherence.
        Organization Secondary Presence Id.

        :return: The organization_secondary_presence_id of this UserScheduleAdherence.
        :rtype: str
        """
        return self._organization_secondary_presence_id

    @organization_secondary_presence_id.setter
    def organization_secondary_presence_id(self, organization_secondary_presence_id):
        """
        Sets the organization_secondary_presence_id of this UserScheduleAdherence.
        Organization Secondary Presence Id.

        :param organization_secondary_presence_id: The organization_secondary_presence_id of this UserScheduleAdherence.
        :type: str
        """
        
        self._organization_secondary_presence_id = organization_secondary_presence_id

    @property
    def routing_status(self):
        """
        Gets the routing_status of this UserScheduleAdherence.
        Actual underlying routing status, used to determine whether a user is actually in adherence when OnQueue

        :return: The routing_status of this UserScheduleAdherence.
        :rtype: str
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this UserScheduleAdherence.
        Actual underlying routing status, used to determine whether a user is actually in adherence when OnQueue

        :param routing_status: The routing_status of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["OFF_QUEUE", "IDLE", "INTERACTING", "NOT_RESPONDING", "COMMUNICATING"]
        if routing_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for routing_status -> " + routing_status)
            self._routing_status = "outdated_sdk_version"
        else:
            self._routing_status = routing_status

    @property
    def actual_activity_category(self):
        """
        Gets the actual_activity_category of this UserScheduleAdherence.
        Activity in which the user is actually engaged

        :return: The actual_activity_category of this UserScheduleAdherence.
        :rtype: str
        """
        return self._actual_activity_category

    @actual_activity_category.setter
    def actual_activity_category(self, actual_activity_category):
        """
        Sets the actual_activity_category of this UserScheduleAdherence.
        Activity in which the user is actually engaged

        :param actual_activity_category: The actual_activity_category of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["OnQueueWork", "Break", "Meal", "Meeting", "OffQueueWork", "TimeOff", "Training", "Unavailable", "Unscheduled"]
        if actual_activity_category.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for actual_activity_category -> " + actual_activity_category)
            self._actual_activity_category = "outdated_sdk_version"
        else:
            self._actual_activity_category = actual_activity_category

    @property
    def is_out_of_office(self):
        """
        Gets the is_out_of_office of this UserScheduleAdherence.
        Whether the user is marked OutOfOffice

        :return: The is_out_of_office of this UserScheduleAdherence.
        :rtype: bool
        """
        return self._is_out_of_office

    @is_out_of_office.setter
    def is_out_of_office(self, is_out_of_office):
        """
        Sets the is_out_of_office of this UserScheduleAdherence.
        Whether the user is marked OutOfOffice

        :param is_out_of_office: The is_out_of_office of this UserScheduleAdherence.
        :type: bool
        """
        
        self._is_out_of_office = is_out_of_office

    @property
    def adherence_state(self):
        """
        Gets the adherence_state of this UserScheduleAdherence.
        The user's current adherence state

        :return: The adherence_state of this UserScheduleAdherence.
        :rtype: str
        """
        return self._adherence_state

    @adherence_state.setter
    def adherence_state(self, adherence_state):
        """
        Sets the adherence_state of this UserScheduleAdherence.
        The user's current adherence state

        :param adherence_state: The adherence_state of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["InAdherence", "OutOfAdherence", "Unscheduled", "Unknown", "Ignored"]
        if adherence_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for adherence_state -> " + adherence_state)
            self._adherence_state = "outdated_sdk_version"
        else:
            self._adherence_state = adherence_state

    @property
    def impact(self):
        """
        Gets the impact of this UserScheduleAdherence.
        The impact of the user's current adherenceState

        :return: The impact of this UserScheduleAdherence.
        :rtype: str
        """
        return self._impact

    @impact.setter
    def impact(self, impact):
        """
        Sets the impact of this UserScheduleAdherence.
        The impact of the user's current adherenceState

        :param impact: The impact of this UserScheduleAdherence.
        :type: str
        """
        allowed_values = ["Positive", "Negative", "Neutral", "Unknown"]
        if impact.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for impact -> " + impact)
            self._impact = "outdated_sdk_version"
        else:
            self._impact = impact

    @property
    def time_of_adherence_change(self):
        """
        Gets the time_of_adherence_change of this UserScheduleAdherence.
        Time when the user entered the current adherenceState in ISO-8601 format

        :return: The time_of_adherence_change of this UserScheduleAdherence.
        :rtype: datetime
        """
        return self._time_of_adherence_change

    @time_of_adherence_change.setter
    def time_of_adherence_change(self, time_of_adherence_change):
        """
        Sets the time_of_adherence_change of this UserScheduleAdherence.
        Time when the user entered the current adherenceState in ISO-8601 format

        :param time_of_adherence_change: The time_of_adherence_change of this UserScheduleAdherence.
        :type: datetime
        """
        
        self._time_of_adherence_change = time_of_adherence_change

    @property
    def presence_update_time(self):
        """
        Gets the presence_update_time of this UserScheduleAdherence.
        Time when presence was last updated.  Used to calculate time in current status. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The presence_update_time of this UserScheduleAdherence.
        :rtype: datetime
        """
        return self._presence_update_time

    @presence_update_time.setter
    def presence_update_time(self, presence_update_time):
        """
        Sets the presence_update_time of this UserScheduleAdherence.
        Time when presence was last updated.  Used to calculate time in current status. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param presence_update_time: The presence_update_time of this UserScheduleAdherence.
        :type: datetime
        """
        
        self._presence_update_time = presence_update_time

    @property
    def active_queues(self):
        """
        Gets the active_queues of this UserScheduleAdherence.
        The list of queues to which this user is joined

        :return: The active_queues of this UserScheduleAdherence.
        :rtype: list[QueueReference]
        """
        return self._active_queues

    @active_queues.setter
    def active_queues(self, active_queues):
        """
        Sets the active_queues of this UserScheduleAdherence.
        The list of queues to which this user is joined

        :param active_queues: The active_queues of this UserScheduleAdherence.
        :type: list[QueueReference]
        """
        
        self._active_queues = active_queues

    @property
    def active_queues_modified_time(self):
        """
        Gets the active_queues_modified_time of this UserScheduleAdherence.
        Time when the list of active queues for this user was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The active_queues_modified_time of this UserScheduleAdherence.
        :rtype: datetime
        """
        return self._active_queues_modified_time

    @active_queues_modified_time.setter
    def active_queues_modified_time(self, active_queues_modified_time):
        """
        Sets the active_queues_modified_time of this UserScheduleAdherence.
        Time when the list of active queues for this user was last updated. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param active_queues_modified_time: The active_queues_modified_time of this UserScheduleAdherence.
        :type: datetime
        """
        
        self._active_queues_modified_time = active_queues_modified_time

    @property
    def removed_from_management_unit(self):
        """
        Gets the removed_from_management_unit of this UserScheduleAdherence.
        For notification purposes. Used to indicate that a user was removed from the management unit

        :return: The removed_from_management_unit of this UserScheduleAdherence.
        :rtype: bool
        """
        return self._removed_from_management_unit

    @removed_from_management_unit.setter
    def removed_from_management_unit(self, removed_from_management_unit):
        """
        Sets the removed_from_management_unit of this UserScheduleAdherence.
        For notification purposes. Used to indicate that a user was removed from the management unit

        :param removed_from_management_unit: The removed_from_management_unit of this UserScheduleAdherence.
        :type: bool
        """
        
        self._removed_from_management_unit = removed_from_management_unit

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UserScheduleAdherence.
        The URI for this object

        :return: The self_uri of this UserScheduleAdherence.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UserScheduleAdherence.
        The URI for this object

        :param self_uri: The self_uri of this UserScheduleAdherence.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class FacebookIntegrationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacebookIntegrationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'page_access_token': 'str',
            'user_access_token': 'str',
            'page_id': 'str',
            'app_id': 'str',
            'app_secret': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'page_access_token': 'pageAccessToken',
            'user_access_token': 'userAccessToken',
            'page_id': 'pageId',
            'app_id': 'appId',
            'app_secret': 'appSecret',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._page_access_token = None
        self._user_access_token = None
        self._page_id = None
        self._app_id = None
        self._app_secret = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FacebookIntegrationRequest.
        The globally unique identifier for the object.

        :return: The id of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FacebookIntegrationRequest.
        The globally unique identifier for the object.

        :param id: The id of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FacebookIntegrationRequest.
        The name of the Facebook Integration

        :return: The name of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FacebookIntegrationRequest.
        The name of the Facebook Integration

        :param name: The name of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._name = name

    @property
    def page_access_token(self):
        """
        Gets the page_access_token of this FacebookIntegrationRequest.
        The long-lived Page Access Token of a facebook page.  See https://developers.facebook.com/docs/facebook-login/access-tokens.  When a pageAccessToken is provided, pageId and userAccessToken are not required.

        :return: The page_access_token of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._page_access_token

    @page_access_token.setter
    def page_access_token(self, page_access_token):
        """
        Sets the page_access_token of this FacebookIntegrationRequest.
        The long-lived Page Access Token of a facebook page.  See https://developers.facebook.com/docs/facebook-login/access-tokens.  When a pageAccessToken is provided, pageId and userAccessToken are not required.

        :param page_access_token: The page_access_token of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._page_access_token = page_access_token

    @property
    def user_access_token(self):
        """
        Gets the user_access_token of this FacebookIntegrationRequest.
        The short-lived User Access Token of the facebook user logged into the facebook app.  See https://developers.facebook.com/docs/facebook-login/access-tokens.  When userAccessToken is provided, pageId is mandatory.  When userAccessToken/pageId combination is provided, pageAccessToken is not required.

        :return: The user_access_token of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._user_access_token

    @user_access_token.setter
    def user_access_token(self, user_access_token):
        """
        Sets the user_access_token of this FacebookIntegrationRequest.
        The short-lived User Access Token of the facebook user logged into the facebook app.  See https://developers.facebook.com/docs/facebook-login/access-tokens.  When userAccessToken is provided, pageId is mandatory.  When userAccessToken/pageId combination is provided, pageAccessToken is not required.

        :param user_access_token: The user_access_token of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._user_access_token = user_access_token

    @property
    def page_id(self):
        """
        Gets the page_id of this FacebookIntegrationRequest.
        The page Id of a facebook page. The pageId is required when userAccessToken is provided.

        :return: The page_id of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """
        Sets the page_id of this FacebookIntegrationRequest.
        The page Id of a facebook page. The pageId is required when userAccessToken is provided.

        :param page_id: The page_id of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._page_id = page_id

    @property
    def app_id(self):
        """
        Gets the app_id of this FacebookIntegrationRequest.
        The app Id of a facebook app. The appId is required when a customer wants to use their own approved facebook app.

        :return: The app_id of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """
        Sets the app_id of this FacebookIntegrationRequest.
        The app Id of a facebook app. The appId is required when a customer wants to use their own approved facebook app.

        :param app_id: The app_id of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._app_id = app_id

    @property
    def app_secret(self):
        """
        Gets the app_secret of this FacebookIntegrationRequest.
        The app Secret of a facebook app. The appSecret is required when appId is provided.

        :return: The app_secret of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._app_secret

    @app_secret.setter
    def app_secret(self, app_secret):
        """
        Sets the app_secret of this FacebookIntegrationRequest.
        The app Secret of a facebook app. The appSecret is required when appId is provided.

        :param app_secret: The app_secret of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._app_secret = app_secret

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FacebookIntegrationRequest.
        The URI for this object

        :return: The self_uri of this FacebookIntegrationRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FacebookIntegrationRequest.
        The URI for this object

        :param self_uri: The self_uri of this FacebookIntegrationRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ObservationValue(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ObservationValue - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'observation_date': 'datetime',
            'conversation_id': 'str',
            'session_id': 'str',
            'requested_routing_skill_ids': 'list[str]',
            'requested_language_id': 'str',
            'routing_priority': 'int',
            'participant_name': 'str',
            'user_id': 'str',
            'direction': 'str',
            'converted_from': 'str',
            'converted_to': 'str',
            'address_from': 'str',
            'address_to': 'str',
            'ani': 'str',
            'dnis': 'str',
            'team_id': 'str',
            'requested_routings': 'list[str]',
            'used_routing': 'str',
            'scored_agents': 'list[AnalyticsScoredAgent]'
        }

        self.attribute_map = {
            'observation_date': 'observationDate',
            'conversation_id': 'conversationId',
            'session_id': 'sessionId',
            'requested_routing_skill_ids': 'requestedRoutingSkillIds',
            'requested_language_id': 'requestedLanguageId',
            'routing_priority': 'routingPriority',
            'participant_name': 'participantName',
            'user_id': 'userId',
            'direction': 'direction',
            'converted_from': 'convertedFrom',
            'converted_to': 'convertedTo',
            'address_from': 'addressFrom',
            'address_to': 'addressTo',
            'ani': 'ani',
            'dnis': 'dnis',
            'team_id': 'teamId',
            'requested_routings': 'requestedRoutings',
            'used_routing': 'usedRouting',
            'scored_agents': 'scoredAgents'
        }

        self._observation_date = None
        self._conversation_id = None
        self._session_id = None
        self._requested_routing_skill_ids = None
        self._requested_language_id = None
        self._routing_priority = None
        self._participant_name = None
        self._user_id = None
        self._direction = None
        self._converted_from = None
        self._converted_to = None
        self._address_from = None
        self._address_to = None
        self._ani = None
        self._dnis = None
        self._team_id = None
        self._requested_routings = None
        self._used_routing = None
        self._scored_agents = None

    @property
    def observation_date(self):
        """
        Gets the observation_date of this ObservationValue.
        The time at which the observation occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The observation_date of this ObservationValue.
        :rtype: datetime
        """
        return self._observation_date

    @observation_date.setter
    def observation_date(self, observation_date):
        """
        Sets the observation_date of this ObservationValue.
        The time at which the observation occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param observation_date: The observation_date of this ObservationValue.
        :type: datetime
        """
        
        self._observation_date = observation_date

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this ObservationValue.
        Unique identifier for the conversation

        :return: The conversation_id of this ObservationValue.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this ObservationValue.
        Unique identifier for the conversation

        :param conversation_id: The conversation_id of this ObservationValue.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def session_id(self):
        """
        Gets the session_id of this ObservationValue.
        The unique identifier of this session

        :return: The session_id of this ObservationValue.
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this ObservationValue.
        The unique identifier of this session

        :param session_id: The session_id of this ObservationValue.
        :type: str
        """
        
        self._session_id = session_id

    @property
    def requested_routing_skill_ids(self):
        """
        Gets the requested_routing_skill_ids of this ObservationValue.
        Unique identifier for a skill requested for an interaction

        :return: The requested_routing_skill_ids of this ObservationValue.
        :rtype: list[str]
        """
        return self._requested_routing_skill_ids

    @requested_routing_skill_ids.setter
    def requested_routing_skill_ids(self, requested_routing_skill_ids):
        """
        Sets the requested_routing_skill_ids of this ObservationValue.
        Unique identifier for a skill requested for an interaction

        :param requested_routing_skill_ids: The requested_routing_skill_ids of this ObservationValue.
        :type: list[str]
        """
        
        self._requested_routing_skill_ids = requested_routing_skill_ids

    @property
    def requested_language_id(self):
        """
        Gets the requested_language_id of this ObservationValue.
        Unique identifier for the language requested for an interaction

        :return: The requested_language_id of this ObservationValue.
        :rtype: str
        """
        return self._requested_language_id

    @requested_language_id.setter
    def requested_language_id(self, requested_language_id):
        """
        Sets the requested_language_id of this ObservationValue.
        Unique identifier for the language requested for an interaction

        :param requested_language_id: The requested_language_id of this ObservationValue.
        :type: str
        """
        
        self._requested_language_id = requested_language_id

    @property
    def routing_priority(self):
        """
        Gets the routing_priority of this ObservationValue.
        Routing priority for the current interaction

        :return: The routing_priority of this ObservationValue.
        :rtype: int
        """
        return self._routing_priority

    @routing_priority.setter
    def routing_priority(self, routing_priority):
        """
        Sets the routing_priority of this ObservationValue.
        Routing priority for the current interaction

        :param routing_priority: The routing_priority of this ObservationValue.
        :type: int
        """
        
        self._routing_priority = routing_priority

    @property
    def participant_name(self):
        """
        Gets the participant_name of this ObservationValue.
        A human readable name identifying the participant

        :return: The participant_name of this ObservationValue.
        :rtype: str
        """
        return self._participant_name

    @participant_name.setter
    def participant_name(self, participant_name):
        """
        Sets the participant_name of this ObservationValue.
        A human readable name identifying the participant

        :param participant_name: The participant_name of this ObservationValue.
        :type: str
        """
        
        self._participant_name = participant_name

    @property
    def user_id(self):
        """
        Gets the user_id of this ObservationValue.
        Unique identifier for the user

        :return: The user_id of this ObservationValue.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this ObservationValue.
        Unique identifier for the user

        :param user_id: The user_id of this ObservationValue.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def direction(self):
        """
        Gets the direction of this ObservationValue.
        The direction of the communication

        :return: The direction of this ObservationValue.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ObservationValue.
        The direction of the communication

        :param direction: The direction of this ObservationValue.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def converted_from(self):
        """
        Gets the converted_from of this ObservationValue.
        Session media type that was converted from in case of a media type conversion

        :return: The converted_from of this ObservationValue.
        :rtype: str
        """
        return self._converted_from

    @converted_from.setter
    def converted_from(self, converted_from):
        """
        Sets the converted_from of this ObservationValue.
        Session media type that was converted from in case of a media type conversion

        :param converted_from: The converted_from of this ObservationValue.
        :type: str
        """
        
        self._converted_from = converted_from

    @property
    def converted_to(self):
        """
        Gets the converted_to of this ObservationValue.
        Session media type that was converted to in case of a media type conversion

        :return: The converted_to of this ObservationValue.
        :rtype: str
        """
        return self._converted_to

    @converted_to.setter
    def converted_to(self, converted_to):
        """
        Sets the converted_to of this ObservationValue.
        Session media type that was converted to in case of a media type conversion

        :param converted_to: The converted_to of this ObservationValue.
        :type: str
        """
        
        self._converted_to = converted_to

    @property
    def address_from(self):
        """
        Gets the address_from of this ObservationValue.
        The address that initiated an action

        :return: The address_from of this ObservationValue.
        :rtype: str
        """
        return self._address_from

    @address_from.setter
    def address_from(self, address_from):
        """
        Sets the address_from of this ObservationValue.
        The address that initiated an action

        :param address_from: The address_from of this ObservationValue.
        :type: str
        """
        
        self._address_from = address_from

    @property
    def address_to(self):
        """
        Gets the address_to of this ObservationValue.
        The address receiving an action

        :return: The address_to of this ObservationValue.
        :rtype: str
        """
        return self._address_to

    @address_to.setter
    def address_to(self, address_to):
        """
        Sets the address_to of this ObservationValue.
        The address receiving an action

        :param address_to: The address_to of this ObservationValue.
        :type: str
        """
        
        self._address_to = address_to

    @property
    def ani(self):
        """
        Gets the ani of this ObservationValue.
        Automatic Number Identification (caller's number)

        :return: The ani of this ObservationValue.
        :rtype: str
        """
        return self._ani

    @ani.setter
    def ani(self, ani):
        """
        Sets the ani of this ObservationValue.
        Automatic Number Identification (caller's number)

        :param ani: The ani of this ObservationValue.
        :type: str
        """
        
        self._ani = ani

    @property
    def dnis(self):
        """
        Gets the dnis of this ObservationValue.
        Dialed number identification service (number dialed by the calling party)

        :return: The dnis of this ObservationValue.
        :rtype: str
        """
        return self._dnis

    @dnis.setter
    def dnis(self, dnis):
        """
        Sets the dnis of this ObservationValue.
        Dialed number identification service (number dialed by the calling party)

        :param dnis: The dnis of this ObservationValue.
        :type: str
        """
        
        self._dnis = dnis

    @property
    def team_id(self):
        """
        Gets the team_id of this ObservationValue.
        The team id the user is a member of

        :return: The team_id of this ObservationValue.
        :rtype: str
        """
        return self._team_id

    @team_id.setter
    def team_id(self, team_id):
        """
        Sets the team_id of this ObservationValue.
        The team id the user is a member of

        :param team_id: The team_id of this ObservationValue.
        :type: str
        """
        
        self._team_id = team_id

    @property
    def requested_routings(self):
        """
        Gets the requested_routings of this ObservationValue.
        All routing types for requested/attempted routing methods

        :return: The requested_routings of this ObservationValue.
        :rtype: list[str]
        """
        return self._requested_routings

    @requested_routings.setter
    def requested_routings(self, requested_routings):
        """
        Sets the requested_routings of this ObservationValue.
        All routing types for requested/attempted routing methods

        :param requested_routings: The requested_routings of this ObservationValue.
        :type: list[str]
        """
        
        self._requested_routings = requested_routings

    @property
    def used_routing(self):
        """
        Gets the used_routing of this ObservationValue.
        Complete routing method

        :return: The used_routing of this ObservationValue.
        :rtype: str
        """
        return self._used_routing

    @used_routing.setter
    def used_routing(self, used_routing):
        """
        Sets the used_routing of this ObservationValue.
        Complete routing method

        :param used_routing: The used_routing of this ObservationValue.
        :type: str
        """
        allowed_values = ["Predictive", "Preferred", "Manual", "Last", "Bullseye", "Standard"]
        if used_routing.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for used_routing -> " + used_routing)
            self._used_routing = "outdated_sdk_version"
        else:
            self._used_routing = used_routing

    @property
    def scored_agents(self):
        """
        Gets the scored_agents of this ObservationValue.


        :return: The scored_agents of this ObservationValue.
        :rtype: list[AnalyticsScoredAgent]
        """
        return self._scored_agents

    @scored_agents.setter
    def scored_agents(self, scored_agents):
        """
        Sets the scored_agents of this ObservationValue.


        :param scored_agents: The scored_agents of this ObservationValue.
        :type: list[AnalyticsScoredAgent]
        """
        
        self._scored_agents = scored_agents

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
WebChatApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class WebChatApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_webchat_deployment(self, deployment_id, **kwargs):
        """
        Delete a WebChat deployment
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_webchat_deployment(deployment_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str deployment_id: Deployment Id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['deployment_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webchat_deployment" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'deployment_id' is set
        if ('deployment_id' not in params) or (params['deployment_id'] is None):
            raise ValueError("Missing the required parameter `deployment_id` when calling `delete_webchat_deployment`")


        resource_path = '/api/v2/webchat/deployments/{deploymentId}'.replace('{format}', 'json')
        path_params = {}
        if 'deployment_id' in params:
            path_params['deploymentId'] = params['deployment_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_webchat_guest_conversation_member(self, conversation_id, member_id, **kwargs):
        """
        Remove a member from a chat conversation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_webchat_guest_conversation_member(conversation_id, member_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str member_id: memberId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'member_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webchat_guest_conversation_member" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `delete_webchat_guest_conversation_member`")
        # verify the required parameter 'member_id' is set
        if ('member_id' not in params) or (params['member_id'] is None):
            raise ValueError("Missing the required parameter `member_id` when calling `delete_webchat_guest_conversation_member`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/members/{memberId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'member_id' in params:
            path_params['memberId'] = params['member_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_webchat_settings(self, **kwargs):
        """
        Remove WebChat deployment settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_webchat_settings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webchat_settings" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/webchat/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_deployment(self, deployment_id, **kwargs):
        """
        Get a WebChat deployment
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_deployment(deployment_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str deployment_id: Deployment Id (required)
        :return: WebChatDeployment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['deployment_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_deployment" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'deployment_id' is set
        if ('deployment_id' not in params) or (params['deployment_id'] is None):
            raise ValueError("Missing the required parameter `deployment_id` when calling `get_webchat_deployment`")


        resource_path = '/api/v2/webchat/deployments/{deploymentId}'.replace('{format}', 'json')
        path_params = {}
        if 'deployment_id' in params:
            path_params['deploymentId'] = params['deployment_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatDeployment',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_deployments(self, **kwargs):
        """
        List WebChat deployments
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_deployments(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: WebChatDeploymentEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_deployments" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/webchat/deployments'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatDeploymentEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_mediarequest(self, conversation_id, media_request_id, **kwargs):
        """
        Get a media request in the conversation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_mediarequest(conversation_id, media_request_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str media_request_id: mediaRequestId (required)
        :return: WebChatGuestMediaRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'media_request_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_mediarequest" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_mediarequest`")
        # verify the required parameter 'media_request_id' is set
        if ('media_request_id' not in params) or (params['media_request_id'] is None):
            raise ValueError("Missing the required parameter `media_request_id` when calling `get_webchat_guest_conversation_mediarequest`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/mediarequests/{mediaRequestId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'media_request_id' in params:
            path_params['mediaRequestId'] = params['media_request_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatGuestMediaRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_mediarequests(self, conversation_id, **kwargs):
        """
        Get all media requests to the guest in the conversation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_mediarequests(conversation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :return: WebChatGuestMediaRequestEntityList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_mediarequests" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_mediarequests`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/mediarequests'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatGuestMediaRequestEntityList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_member(self, conversation_id, member_id, **kwargs):
        """
        Get a web chat conversation member
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_member(conversation_id, member_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str member_id: memberId (required)
        :return: WebChatMemberInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'member_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_member" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_member`")
        # verify the required parameter 'member_id' is set
        if ('member_id' not in params) or (params['member_id'] is None):
            raise ValueError("Missing the required parameter `member_id` when calling `get_webchat_guest_conversation_member`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/members/{memberId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'member_id' in params:
            path_params['memberId'] = params['member_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatMemberInfo',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_members(self, conversation_id, **kwargs):
        """
        Get the members of a chat conversation.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_members(conversation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param int page_size: The number of entries to return per page, or omitted for the default.
        :param int page_number: The page number to return, or omitted for the first page.
        :param bool exclude_disconnected_members: If true, the results will not contain members who have a DISCONNECTED state.
        :return: WebChatMemberInfoEntityList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'page_size', 'page_number', 'exclude_disconnected_members']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_members" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_members`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/members'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'exclude_disconnected_members' in params:
            query_params['excludeDisconnectedMembers'] = params['exclude_disconnected_members']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatMemberInfoEntityList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_message(self, conversation_id, message_id, **kwargs):
        """
        Get a web chat conversation message
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_message(conversation_id, message_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str message_id: messageId (required)
        :return: WebChatMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'message_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_message" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_message`")
        # verify the required parameter 'message_id' is set
        if ('message_id' not in params) or (params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `get_webchat_guest_conversation_message`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/messages/{messageId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatMessage',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_guest_conversation_messages(self, conversation_id, **kwargs):
        """
        Get the messages of a chat conversation.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_guest_conversation_messages(conversation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str after: If available, get the messages chronologically after the id of this message
        :param str before: If available, get the messages chronologically before the id of this message
        :param str sort_order: Sort order
        :param int max_results: Limit the returned number of messages, up to a maximum of 100
        :return: WebChatMessageEntityList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'after', 'before', 'sort_order', 'max_results']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_guest_conversation_messages" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_webchat_guest_conversation_messages`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/messages'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']

        query_params = {}
        if 'after' in params:
            query_params['after'] = params['after']
        if 'before' in params:
            query_params['before'] = params['before']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']
        if 'max_results' in params:
            query_params['maxResults'] = params['max_results']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatMessageEntityList',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_webchat_settings(self, **kwargs):
        """
        Get WebChat deployment settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_webchat_settings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: WebChatSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webchat_settings" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/webchat/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_webchat_guest_conversation_mediarequest(self, conversation_id, media_request_id, body, **kwargs):
        """
        Update a media request in the conversation, setting the state to ACCEPTED/DECLINED/ERRORED
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_webchat_guest_conversation_mediarequest(conversation_id, media_request_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str media_request_id: mediaRequestId (required)
        :param WebChatGuestMediaRequest body: Request (required)
        :return: WebChatGuestMediaRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'media_request_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_webchat_guest_conversation_mediarequest" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `patch_webchat_guest_conversation_mediarequest`")
        # verify the required parameter 'media_request_id' is set
        if ('media_request_id' not in params) or (params['media_request_id'] is None):
            raise ValueError("Missing the required parameter `media_request_id` when calling `patch_webchat_guest_conversation_mediarequest`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `patch_webchat_guest_conversation_mediarequest`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/mediarequests/{mediaRequestId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'media_request_id' in params:
            path_params['mediaRequestId'] = params['media_request_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatGuestMediaRequest',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_webchat_deployments(self, body, **kwargs):
        """
        Create WebChat deployment
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_webchat_deployments(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param WebChatDeployment body: Deployment (required)
        :return: WebChatDeployment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_webchat_deployments" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_webchat_deployments`")


        resource_path = '/api/v2/webchat/deployments'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatDeployment',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_webchat_guest_conversation_member_messages(self, conversation_id, member_id, body, **kwargs):
        """
        Send a message in a chat conversation.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_webchat_guest_conversation_member_messages(conversation_id, member_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str member_id: memberId (required)
        :param CreateWebChatMessageRequest body: Message (required)
        :return: WebChatMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'member_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_webchat_guest_conversation_member_messages" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `post_webchat_guest_conversation_member_messages`")
        # verify the required parameter 'member_id' is set
        if ('member_id' not in params) or (params['member_id'] is None):
            raise ValueError("Missing the required parameter `member_id` when calling `post_webchat_guest_conversation_member_messages`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_webchat_guest_conversation_member_messages`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/members/{memberId}/messages'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'member_id' in params:
            path_params['memberId'] = params['member_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatMessage',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_webchat_guest_conversation_member_typing(self, conversation_id, member_id, **kwargs):
        """
        Send a typing-indicator in a chat conversation.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_webchat_guest_conversation_member_typing(conversation_id, member_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: conversationId (required)
        :param str member_id: memberId (required)
        :return: WebChatTyping
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'member_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_webchat_guest_conversation_member_typing" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `post_webchat_guest_conversation_member_typing`")
        # verify the required parameter 'member_id' is set
        if ('member_id' not in params) or (params['member_id'] is None):
            raise ValueError("Missing the required parameter `member_id` when calling `post_webchat_guest_conversation_member_typing`")


        resource_path = '/api/v2/webchat/guest/conversations/{conversationId}/members/{memberId}/typing'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'member_id' in params:
            path_params['memberId'] = params['member_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Guest Chat JWT']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatTyping',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_webchat_guest_conversations(self, body, **kwargs):
        """
        Create an ACD chat conversation from an external customer.
        This endpoint will create a new ACD Chat conversation under the specified Chat Deployment.  The conversation will begin with a guest member in it (with a role=CUSTOMER) according to the customer information that is supplied. If the guest member is authenticated, the 'memberAuthToken' field should include his JWT as generated by the 'POST /api/v2/signeddata' resource; if the guest member is anonymous (and the Deployment permits it) this field can be omitted.  The returned data includes the IDs of the conversation created, along with a newly-create JWT token that you can supply to all future endpoints as authentication to perform operations against that conversation. After successfully creating a conversation, you should connect a websocket to the event stream named in the 'eventStreamUri' field of the response; the conversation is not routed until the event stream is attached.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_webchat_guest_conversations(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param CreateWebChatConversationRequest body: CreateConversationRequest (required)
        :return: CreateWebChatConversationResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_webchat_guest_conversations" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_webchat_guest_conversations`")


        resource_path = '/api/v2/webchat/guest/conversations'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='CreateWebChatConversationResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_webchat_deployment(self, deployment_id, body, **kwargs):
        """
        Update a WebChat deployment
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_webchat_deployment(deployment_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str deployment_id: Deployment Id (required)
        :param WebChatDeployment body: Deployment (required)
        :return: WebChatDeployment
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['deployment_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_webchat_deployment" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'deployment_id' is set
        if ('deployment_id' not in params) or (params['deployment_id'] is None):
            raise ValueError("Missing the required parameter `deployment_id` when calling `put_webchat_deployment`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_webchat_deployment`")


        resource_path = '/api/v2/webchat/deployments/{deploymentId}'.replace('{format}', 'json')
        path_params = {}
        if 'deployment_id' in params:
            path_params['deploymentId'] = params['deployment_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatDeployment',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_webchat_settings(self, body, **kwargs):
        """
        Update WebChat deployment settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_webchat_settings(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param WebChatSettings body: webChatSettings (required)
        :return: WebChatSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_webchat_settings" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_webchat_settings`")


        resource_path = '/api/v2/webchat/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='WebChatSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
